@@ -436,7 +436,7 @@ class RESTAPI :
                 api_url=URL['championmasteries'].format(url='/')
                 championMastery = r_api.get_champ_mastery_by_summoner_id_and_champ_id(summoner['id'], participant['championId'])
                 print(championMastery)
-                self.post_championMastery(championMastery[0])
+                self.post_championMastery(championMastery)
         
             response = self.get_matchparticipant_by_matchid_and_puuid(match['metadata']['matchId'], puuid)
             if (len(response) == 0) :
